CleverPush class

Constructors

CleverPush()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSubscriptionTag(String id) Future
addSubscriptionTags(List<String> tagIds) Future
areNotificationsEnabled() Future<bool?>
clearNotificationsFromNotificationCenter() Future
disableAppBanners() Future<void>
enableAppBanners() Future<void>
enableDevelopmentMode() Future<void>
getAvailableAttributes() Future<List>
getAvailableTags() Future<List>
getAvailableTopics() Future<List<CPTopic>>
getDeviceToken() Future<String>
getHandleUniversalLinksInAppForDomains() Future<List<String>?>
getNotifications() Future<List<CPNotification>>
getNotificationsWithApi(bool combineWithApi) Future<List<CPNotification>>
getSubscriptionAttribute(String id) Future
getSubscriptionAttributes() Future<Map>
getSubscriptionId() Future<String>
getSubscriptionTags() Future<List>
getSubscriptionTopics() Future<List>
init(String channelId, [bool autoRegister = true]) Future<void>
isSubscribed() Future<bool?>
markSubscriptionAsTest() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pullSubscriptionAttributeValue(String id, String value) Future
pushSubscriptionAttributeValue(String id, String value) Future
removeAllNotifications() Future
removeNotification(String notificationId, {bool removeFromNotificationCenter = false}) Future<void>
removeSubscriptionAttribute(String attributeId) Future
removeSubscriptionAttributes(List<String> attributeIds) Future
removeSubscriptionTag(String id) Future
removeSubscriptionTags(List<String> tagIds) Future
setAppBannerOpenedHandler(AppBannerOpenedHandler handler) → void
setAppBannerShownHandler(AppBannerShownHandler handler) → void
setAuthorizerToken(String token) Future
setAutoRequestNotificationPermission(bool autoRequest) Future
setBrandingColor(String color) → void
setChatUrlOpenedHandler(ChatUrlOpenedHandler handler) → void
setHandleUniversalLinksInAppForDomains(List<String>? domains) Future<void>
setHandleUrlFromSceneDelegate(bool handleFromSceneDelegate) Future<void>
setIgnoreDisabledNotificationPermission(bool ignore) Future
setInitializedHandler(InitializationHandler handler) → void
setLogHandler(LogHandler handler) → void
setMaximumNotificationCount(int count) Future
setNotificationOpenedHandler(NotificationOpenedHandler handler) → void
setNotificationReceivedHandler(NotificationReceivedHandler handler) → void
setProvisionalNotificationAuthorizationEnabled(bool enabled) Future<void>
setShowNotificationsInForeground(bool show) Future<void>
setSubscribedHandler(SubscribedHandler handler) → void
setSubscriptionAttribute(String id, String value) Future
setSubscriptionCountry(String country) Future
setSubscriptionHandler(SubscriptionHandler handler) → void
setSubscriptionLanguage(String language) Future
setSubscriptionTopics(List<String> topics) Future
setSubscriptionTopicsHandler(SubscriptionTopicsHandler handler) → void
setTrackingConsent(bool hasConsent) Future
setTrackingConsentRequired(bool consentRequired) Future
showAppBanner(String id, [void closedHandler()?]) Future
showTopicsDialog() Future<void>
subscribe() Future<String>
toString() String
A string representation of this object.
inherited
trackEvent(String eventName, [dynamic argument]) Future
trackPageView(String url) Future
triggerFollowUpEvent(String eventName, [Map<String, String> parameters = const {}]) Future
unmarkSubscriptionAsTest() Future
unsubscribe() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared CleverPush
getter/setter pair