CleverPushStoryViewSize enum

Story view size (height/width)

Inheritance
Available extensions

Values

matchParent → const CleverPushStoryViewSize
wrapContent → const CleverPushStoryViewSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toNativeValue int

Available on CleverPushStoryViewSize, provided by the CleverPushStoryViewSizeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CleverPushStoryViewSize>
A constant List of the values in this enum, in order of their declaration.